---
name: "🐞 Bug Report"
about: "Report an issue to help the project improve."
title: "[Bug] "
labels: "Type: Bug"


---

# **🐞 Bug Report**

## **Describe the bug**
<!-- A clear and concise description of what the bug is. -->

*

---

### **Is this a regression?**
<!-- Did this behaviour used to work in the previous version? -->
<!-- Yes, the last version in which this bug was not present was: ... -->

---

### **To Reproduce**

<!-- Steps to reproduce the error:
(e.g.:)
1. Use x argument / navigate to
2. Fill this information
3. Go to...
4. See error -->

<!-- Write the steps here (add or remove as many steps as needed)-->

1.
2.
3.
4.

---

### **Expected behaviour**
<!-- A clear and concise description of what you expected to happen. -->

*

---

### **Media prove**
<!-- If applicable, add screenshots or videos to help explain your problem. -->

---

### **Your environment**

<!-- use all the applicable bulleted list elements for this specific issue,
and remove all the bulleted list elements that are not relevant for this issue. -->

* OS: <!--[e.g. Ubuntu 5.4.0-26-generic x86_64 / Windows 1904 ...]-->
* Python version:
* Pip version:

---

### **Additional context**
<!-- Add any other context or additional information about the problem here.-->

*

<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->
